<h1>mycdp 🌐 <a href="https://pypi.python.org/pypi/mycdp" target="_blank"><img src="https://img.shields.io/pypi/v/mycdp.svg?color=3399EE" alt="PyPI version" /></a></h1>

### **[mycdp](https://pypi.python.org/pypi/mycdp)** is a collection of autogenerated CDP (Chrome DevTools Protocol) utilities for advanced Chromium automation with Python.
